=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2008-12-19 06:12:28 +0000
+++ bzrlib/msgeditor.py	2009-01-30 08:24:38 +0000
@@ -248,7 +248,7 @@
     from bzrlib.status import show_tree_status
     status_tmp = StringIO()
     show_tree_status(working_tree, specific_files=specific_files, 
-                     to_file=status_tmp)
+                     to_file=status_tmp, verbose=True)
     return status_tmp.getvalue()
 
 

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2008-12-19 06:12:28 +0000
+++ bzrlib/tests/test_msgeditor.py	2009-01-30 08:24:38 +0000
@@ -81,6 +81,38 @@
   hell\u00d8
 """)
 
+    def make_multiple_pending_tree(self):
+        from bzrlib import config
+        config.GlobalConfig().set_user_option('email',
+                                              'Bilbo Baggins <bb@hobbit.net>')
+        tree = self.make_branch_and_tree('a')
+        tree.commit('Initial checkin.', timestamp=1230912900, timezone=0)
+        tree2 = tree.bzrdir.clone('b').open_workingtree()
+        tree.commit('Minor tweak.', timestamp=1231977840, timezone=0)
+        tree2.commit('Feature X work.', timestamp=1233186240, timezone=0)
+        tree3 = tree2.bzrdir.clone('c').open_workingtree()
+        tree2.commit('Feature X finished.', timestamp=1233187680, timezone=0)
+        tree3.commit('Feature Y, based on initial X work.',
+                     timestamp=1233285960, timezone=0)
+        tree.merge_from_branch(tree2.branch)
+        tree.merge_from_branch(tree3.branch)
+        return tree
+
+    def test_commit_template_pending_merges(self):
+        """Test building a commit message template when there are pending
+        merges.  The commit message should show all pending merge revisions,
+        as does 'status -v', not only the merge tips.
+        """
+        working_tree = self.make_multiple_pending_tree()
+        template = msgeditor.make_commit_message_template(working_tree, None)
+        self.assertEqualDiff(template,
+u"""\
+pending merges:
+  Bilbo Baggins 2009-01-29 Feature X finished.
+    Bilbo Baggins 2009-01-28 Feature X work.
+  Bilbo Baggins 2009-01-30 Feature Y, based on initial X work.
+""")
+
     def test_commit_template_encoded(self):
         """Test building a commit message template"""
         working_tree = self.make_uncommitted_tree()

